@@ -22,10 +22,14 @@
 #include "settingsdialog.h"
 #include "aboutdialog.h"
 #include "puzzleitem.h"
+#include "statistics.h"
+#include "statisticsdialog.h"
 
 #include <QAction>
 #include <QMenu>
 #include <QMenuBar>
+#include <QMessageBox>
+#include <QCloseEvent>
 
 #include <QDebug>
 
@@ -59,11 +63,14 @@ MainWindow *MainWindow::instance()
 
 void MainWindow::createMenu()
 {
-    menu_ = menuBar()->addMenu("");
+    menu_ = menuBar()->addMenu("&Game");
     menu_->addAction(newGameAction_);
+    menu_->addAction(statisticsAction_);
     menu_->addAction(saveAction_);
-    menu_->addAction(aboutAction_);
     menu_->addAction(importAction_);
+
+    helpMenu_ = menuBar()->addMenu("&Help");
+    helpMenu_->addAction(aboutAction_);
 }
 
 void MainWindow::createActions()
@@ -81,6 +88,9 @@ void MainWindow::createActions()
     saveAction_ = new QAction(tr("Save and quit"), this);
     connect(saveAction_, SIGNAL(triggered()), GameView::instance(), SLOT(saveGame()));
     saveAction_->setDisabled(true);
+
+    statisticsAction_ = new QAction(tr("Statistics"), this);
+    connect(statisticsAction_, SIGNAL(triggered()), this, SLOT(showStatistics()));
 }
 
 void MainWindow::importClicked()
@@ -90,11 +100,13 @@ void MainWindow::importClicked()
 
 void MainWindow::newGameClicked()
 {
-    settingsDialog_->exec();
+    int r = settingsDialog_->exec();
 
-    GameView::instance()->setPieces(ImageImporter::instance()->newPieces(Settings::instance()->image(), Settings::instance()->pieceCount()));
-    enableSaving();
-    PuzzleItem::setMoveCount(0);
+    if(r) {
+        GameView::instance()->setPieces(ImageImporter::instance()->newPieces(Settings::instance()->image(), Settings::instance()->pieceCount()));
+        enableSaving();
+        PuzzleItem::setMoveCount(0);
+    }
 }
 
 void MainWindow::aboutClicked()
@@ -108,6 +120,9 @@ void MainWindow::gameEnded()
 {
     if(saveAction_->isEnabled()) {
         saveAction_->setDisabled(true);
+        Statistics::instance()->increaseGameCount(Settings::instance()->pieceCount() == EASY_PIECE_COUNT ? Statistics::easyDifficulty : Statistics::hardDifficulty);
+        Statistics::instance()->addNewScore(PuzzleItem::moveCount(),
+                                            Settings::instance()->pieceCount() == EASY_PIECE_COUNT ? Statistics::easyDifficulty : Statistics::hardDifficulty);
         PuzzleItem::resetMoveCount();
     }
 }
@@ -118,3 +133,24 @@ void MainWindow::enableSaving()
         saveAction_->setEnabled(true);
     }
 }
+
+void MainWindow::closeEvent(QCloseEvent *event)
+{
+    if(saveAction_->isEnabled()) {
+        int answer = QMessageBox::question(this, tr("Save game status?"),
+                                           tr("Saved status will be automatically loaded when you start the application next time"),
+                                           QMessageBox::Yes, QMessageBox::No);
+
+        if(answer == QMessageBox::Yes) {
+            GameView::instance()->saveGame();
+        }
+    }
+
+    event->accept();
+}
+
+void MainWindow::showStatistics()
+{
+    StatisticsDialog dialog(this);
+    dialog.exec();
+}
